@@ -1,4 +1,3 @@
-readline("Press <Enter> to continue:")
 opar = par (ask = dev.interactive (orNone = TRUE) )
 readline("Press <Enter> to continue:")
 data(course.df)
@@ -9,17 +8,17 @@ Exam
 readline("Press <Enter> to continue:")
 stripchart(Exam,method="stack",pch=1,main="STATS 20x Exam marks",xlab="exam mark")
 readline("Press <Enter> to continue:")
-layout.20x(1,2)
+layout20x(1,2)
 readline("Press <Enter> to continue:")
 hist(Exam)
 readline("Press <Enter> to continue:")
 plot(density(Exam))
 readline("Press <Enter> to continue:")
-numerical.summary(Exam)
+summaryStats(Exam)
 readline("Press <Enter> to continue:")
 t.test(Exam)
 readline("Press <Enter> to continue:")
-layout.20x(1,1)
+layout20x(1,1)
 readline("Press <Enter> to continue:")
 detach(course.df)
 readline("Press <Enter> to continue:")
